pub struct OpponentStateBot {
pub bot: Bot,
pub inventory: Vec<Item>,
}Fields
bot: Botinventory: Vec<Item>Trait Implementations
Sourceimpl Clone for OpponentStateBot
impl Clone for OpponentStateBot
Sourcefn clone(&self) -> OpponentStateBot
fn clone(&self) -> OpponentStateBot
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpponentStateBot
impl Debug for OpponentStateBot
Sourceimpl<'de> Deserialize<'de> for OpponentStateBot
impl<'de> Deserialize<'de> for OpponentStateBot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OpponentStateBot
impl JsonSchema for OpponentStateBot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OpponentStateBot
impl PartialEq for OpponentStateBot
Sourceimpl Serialize for OpponentStateBot
impl Serialize for OpponentStateBot
Sourceimpl Tsify for OpponentStateBot
impl Tsify for OpponentStateBot
const DECL: &'static str = "export interface OpponentStateBot {\n bot: Bot;\n inventory: Item[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for OpponentStateBot
impl StructuralPartialEq for OpponentStateBot