pub struct OpponentStateHuman {
pub character_state: CharacterState,
}Fields
character_state: CharacterStateTrait Implementations
Sourceimpl Clone for OpponentStateHuman
impl Clone for OpponentStateHuman
Sourcefn clone(&self) -> OpponentStateHuman
fn clone(&self) -> OpponentStateHuman
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpponentStateHuman
impl Debug for OpponentStateHuman
Sourceimpl<'de> Deserialize<'de> for OpponentStateHuman
impl<'de> Deserialize<'de> for OpponentStateHuman
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OpponentStateHuman
impl JsonSchema for OpponentStateHuman
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OpponentStateHuman
impl PartialEq for OpponentStateHuman
Sourceimpl Serialize for OpponentStateHuman
impl Serialize for OpponentStateHuman
Sourceimpl Tsify for OpponentStateHuman
impl Tsify for OpponentStateHuman
const DECL: &'static str = "export interface OpponentStateHuman {\n character_state: CharacterState;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for OpponentStateHuman
impl StructuralPartialEq for OpponentStateHuman